/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package cmdTools.segmentation;

import jargs.gnu.CmdLineParser;

import de.unihalle.informatik.MiToBo.datatypes.images.*;
import de.unihalle.informatik.MiToBo.segmentation.thresholds.*;
import de.unihalle.informatik.MiToBo.io.files.*;

/**
 * Commandline tool for thresholding plain images, stacks and hyperstacks 
 * of 8 or 16 Bit grayvalue type.
 * 
 * @author gress
 *
 */
public class ImageThresholdTool {
	
	public static void main(String [] args) {
		CmdLineParser parser = new CmdLineParser();
		CmdLineParser.Option oThreshold = parser.addDoubleOption('t',"threshold");
		CmdLineParser.Option oFGValue = parser.addDoubleOption('f',"fgvalue");
		CmdLineParser.Option oBGValue = parser.addDoubleOption('b',"bgvalue");

		// parse arguments
		try {
			parser.parse(args);
		}
		catch ( CmdLineParser.OptionException e ) {
			System.err.println(e.getMessage());
			printUsage();
			System.exit(2);
		}

		// remaining arguments ok?
		String[] otherArgs = parser.getRemainingArgs();
		if (otherArgs.length != 2) {
			printUsage();
			System.exit(2);
		}

		// retrieve options
		Double threshold = (Double)parser.getOptionValue( oThreshold, null);
		@SuppressWarnings("boxing")
    Double fgValue = 
			(Double)parser.getOptionValue(oFGValue, Double.POSITIVE_INFINITY);
		@SuppressWarnings("boxing")
    Double bgValue = 
			(Double)parser.getOptionValue( oBGValue, Double.POSITIVE_INFINITY);

		try {
			ImageOpen IO = new ImageOpen(otherArgs[0], null, true, 0);
			IO.runOp(null);
			MTBImage inImg =	IO.getImage();

			ImgThresh thresOp = new ImgThresh();
			thresOp.setInput("InputImage", inImg);
			thresOp.setParameter("Threshold", threshold); 
			thresOp.setParameter("FGValue", fgValue);
			thresOp.setParameter("BGValue", bgValue);

			thresOp.runOp(null);

			MTBImage resultImg = (MTBImage)thresOp.getOutput( "ResultImage");
			ImageSave writer= new ImageSave(otherArgs[1], resultImg, true, true);
			writer.runOp(null);
		} catch ( Exception e) {
			e.printStackTrace();
		}
	}

	private static void printUsage() {
		System.err.println( "Usage: Threshold_Image " +
				"[-t threshold] [--threshold threshold] " +
				"[-f foregroundValue] [--FGValue foregroundValue] " +
				"[-b backgroundValue] [--BGValue backgroundValue] " +
				"\n" +
				"image resultImage"
		);
	}
}
