/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.datatypes;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * A set of double values, stored in an 2D double array object to be used as
 * input or output to MTB operators.
 * 
 * @modified Sep 27, 2010
 * 
 * @author Birgit Möller
 */
public class MTBDoubleArray2DData extends MTBData {
		/**
		 * The 2D double array object.
		 */
		private double[][] array;

		/**
		 * Construct a 2D set of double values from the given 2D double array.
		 * 
		 * @param a
		 *          2D array with double values
		 */
		public MTBDoubleArray2DData(double[][] a) {
				this.array = a;
		}

		/**
		 * Returns the MTBDoubleArray2DData object.
		 * 
		 * @return 2D set of double values.
		 */
		public double[][] getArray() {
				return this.array;
		}

		/**
		 * Set the double values of these object.
		 * 
		 * @param a
		 *          double values to set
		 */
		public void setArray(double[][] a) {
				this.array = a;
		}

		/**
		 * Get double value at the given position.
		 * 
		 * @param i
		 *          index of the double value at second dimension
		 * @param j
		 *          index of the double value at first dimension
		 * @return Value at position i,j.
		 */
		public double getValue(int i, int j) {
				return this.array[j][i];
		}

		/**
		 * Set double value at given position.
		 * 
		 * @param i
		 *          index of the double value to set at second dimension
		 * @param j
		 *          index of the double value to set at first dimension
		 * @param val
		 *          double value to set
		 */
		public void setValue(int i, int j, double val) {
				this.array[j][i] = val;
		}
}
