/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.datatypes;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * An 1D integer array to be used as input or output to MTB operators.
 * 
 *@modified Sep 29, 2010
 * 
 * @author Birgit Möller
 */

public class MTBIntegerArray1DData extends MTBData {
		/**
		 * 1D integer array to store the data.
		 */
		private int[] array;

		/**
		 * Construct an data set of integer values from the given array data.
		 * 
		 * @param a
		 *          array data.
		 */
		public MTBIntegerArray1DData(int[] a) {
				this.array = a;
		}

		/**
		 * Return the array data.
		 * 
		 * @return Array data.
		 */
		public int[] getArray() {
				return this.array;
		}

		/**
		 * Set the array data.
		 * 
		 * @param a
		 *          array data
		 */
		public void setArray(int[] a) {
				this.array = a;
		}

		/**
		 * Return the integer value from the array data an given position.
		 * 
		 * @param i
		 *          position
		 */
		public int getValue(int i) {
				return this.array[i];
		}

		/**
		 * Set integer value of the array data at given position.
		 * 
		 * @param i
		 *          position
		 * @param val
		 *          integer value at i-th position of the array data
		 */
		public void setValue(int i, int val) {
				this.array[i] = val;
		}

		/**
		 * Return current length (size) of the array data.
		 * 
		 * @return Containing number of integer values in the array data.
		 */
		public int length() {
				return this.array.length;
		}
}
