/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.datatypes;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * An 2D integer array to be used as input or output to MTB operators.
 * 
 *@modified Sep 29, 2010
 * 
 * @author Birgit Möller
 */

public class MTBIntegerArray2DData extends MTBData {
		/**
		 * 2D integer array to store the array data.
		 */
		private int[][] array;

		/**
		 * Construct an 2D data set of integer values from the given array data.
		 * 
		 * @param a
		 *          array data
		 */
		public MTBIntegerArray2DData(int[][] a) {
				this.array = a;
		}

		/**
		 * Return the array data.
		 * 
		 * @return Array data.
		 */
		public int[][] getArray() {
				return this.array;
		}

		/**
		 * Set the array data from the given 2D integer array.
		 * 
		 * @param a
		 *          Array data to set.
		 */
		public void setArray(int[][] a) {
				this.array = a;
		}

		/**
		 * Return the integer value of the array data at the given position [i][j].
		 * 
		 * @param i
		 *          position of second dimension
		 * @param j
		 *          position of first dimension
		 * @return Integer value of the array data at position [j][i].
		 */
		public int getValue(int i, int j) {
				return this.array[j][i];
		}

		/**
		 * Set integer value of the array data at given position [j][i].
		 * 
		 * @param i
		 *          position of second dimension
		 * @param j
		 *          position of first dimension
		 * @param val
		 *          integer value for the array data at i-th position
		 */
		public void setValue(int i, int j, int val) {
				this.array[j][i] = val;
		}
}
