/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.exceptions;

public class MTBOperatorException extends MTBException {

	public static enum OperatorExceptionType {
		VALIDATION_FAILED,
		OPERATE_FAILED,
		UNKOWN_NAME,
		INVALID_CLASS,
		MTB_DATA_REQUIRED,
		ILLEGAL_EXTENSION,
		UNSPECIFIED_ERROR
	}

	private static final String typeID= "MTBOperatorException";
	
	protected OperatorExceptionType type;
	
	public MTBOperatorException(OperatorExceptionType t, String c) {
		this.type= t;
		this.comment= c;
	}

	@Override
	public String getIdentString() {
		switch(this.type)
		{
		case VALIDATION_FAILED:
			return typeID + ": argument validation failed!\n "
				+ "--> mandatory arguments are missing or wrong parameter range!!!";
		case OPERATE_FAILED:
			return typeID + ": operate()-call failed!";
		case UNKOWN_NAME:
			return typeID + ": unkown argument name";
		case INVALID_CLASS:
			return typeID + ": invalid class to set argument value";
		case MTB_DATA_REQUIRED:
			return typeID + ": class derived from MTBData required";
		case ILLEGAL_EXTENSION:
			return typeID + ": illegal extension in filename ";
		case UNSPECIFIED_ERROR:
			return typeID + ": operator run failed - unknown reason!";			
		}
		return null;
	}
}
