/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.io.tools;

import java.util.Vector;

////-*-c++-*- ***********************************************************
////
///** \file        sourceHDConfig.cc
// *  \brief       Implements class "sourceHDConfig".
// *
// *  \author      Birgit Moeller (bimoelle@TechFak.uni-bielefeld.de)
// *  \date        November 13, 2003
// *
// */
//// last update:  13.11.2003 by Birgit Moeller
////               8.9.2004 by Denis Williams - added step via %
////                        (e.g. 1-100%3 take every third image starting
////                        with 1 and with maximum 100, 1 4 7...)
//// ********************************************************************
////********************************************************************
////private utilities
//
///* #[ parseIndices : */
//
///**
//*  This function implements a parser for image index ranges.
//*  Given the std::string, ranges separated by commas are extracted and 
//*  resulting indices written to a std::vector. A range may consist
//*  of a single value or two values separated by a hyphen:
//*
//*  1,2,3,4  or 1,3-5,68 or 1-5 or ...
//*/

/**
 * 
 * 
 * This function implements a parser for image index ranges. Given the string,
 * ranges separated by commas are extracted and resulting indices written to a
 * vector. A range may consist of a single value or two values separated by a
 * hyphen:
 * <p>
 * 1,2,3,4 or 1,3-5,68 or 1-5 or 1-100%3 take every third image starting with 1
 * and with maximum 100, 1 4 7...
 * <p>
 * !!! No test if first index is smaller the second index, user has to care
 * about it !!!
 * <p>
 * >>> Original class by Birgit Moeller and Denis Williams. Class was converted
 * from C++ to Java by Danny Misiak. <<<
 * 
 * @modified 17.11.2009
 * 
 * @author misiak
 */

public class IndexParser {

  public int[] parseIndices(String indexString) {
    int firstID; // first index of range
    int lastID; // last index of range
    int length = indexString.length(); // length of given string
    String substring; // current substring to be processed
    int posGlobal = 0; // global position in given string
    int posLocal = 0; // local position in current substring
    int firstPos = 0; // start index of analyzed substring
    int secondPos = 0; // end index of analyzed substring
    int posLocal2 = 0; // start index of step size substring
    int step;
    Vector<Integer> indices = new Vector<Integer>();
    // parse the whole string
    while (posGlobal < length) {
      // search for ','

      while (posGlobal < length) {
        if (indexString.charAt(posGlobal) != ',')
          posGlobal++;
        else
          break;
      }
      secondPos = posGlobal;
      // search for hyphen in substring
      posLocal = firstPos;
      while (posLocal < secondPos) {
        if (indexString.charAt(posLocal) != '-')
          posLocal++;
        else
          break;
      }
      // found one
      if (posLocal < secondPos) {
        // first index
        substring = indexString.substring(firstPos, posLocal);
        firstID = Integer.parseInt(substring);

        // search for percent in substring
        posLocal2 = posLocal;
        while (posLocal2 < secondPos) {
          if (indexString.charAt(posLocal2) != '%')
            posLocal2++;
          else
            break;
        }
        // found percent
        if (posLocal2 < secondPos) {
          substring = indexString.substring(posLocal2 + 1, secondPos);
          step = Integer.parseInt(substring);
        } else
          step = 1;
        // second index
        substring = indexString.substring(posLocal + 1, posLocal2);
        lastID = Integer.parseInt(substring);
        // fill index list
        for (int ID = firstID; ID <= lastID; ID += step) {
          indices.add(ID);
        }
        // no hyphen detected
      } else {
        substring = indexString.substring(firstPos, secondPos);
        indices.add(Integer.parseInt(substring));
      }
      posGlobal = secondPos + 1;
      firstPos = posGlobal;
    }
    // copy the index values to a integer array and return the indices
    int[] resultIndices = new int[indices.size()];
    for (int i = 0; i < indices.size(); i++) {
      resultIndices[i] = indices.elementAt(i);
    }
    return (resultIndices);
  }
}
