/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;
 
import java.io.File;
import java.util.*;
 
import org.graphdrawing.graphml.xmlns.*;
import org.apache.xmlbeans.XmlString;
 
public class GraphmlHelper {
 
	private static boolean debug = false;

	public GraphmlHelper( ) {
	}
    
    static public void printGraphml( GraphmlType graphml) {

		System.out.println( "desc " + graphml.getDesc());
        
		for ( int k = 0 ; k < graphml.sizeOfKeyArray() ; k++ ) {
			KeyType key = graphml.getKeyArray( k);
			System.out.println( "   " + key.getId());
		}

		GraphType topG = getToplevelGraph( graphml);
		printGraph( topG, "");
    }
    
	static public void printGraph( GraphType graph , String indent) {
		if ( debug ) 
			System.out.println( indent + "printGraph " + graph.getId());

		for ( int n = 0 ; n < graph.sizeOfNodeArray() ; n++ ) {
			printNode( graph.getNodeArray( n), indent + "  ");
		}

		for ( int e = 0 ; e < graph.sizeOfEdgeArray() ; e++ ) {
			printEdge( graph.getEdgeArray( e), indent + "  ");
		}

		for ( int d = 0 ; d < graph.sizeOfDataArray() ; d++ ) {
			printData( graph.getDataArray( d), indent + "  ");
		}
	}

	static public void printNode( NodeType node, String indent) {
		System.out.println( indent + "printNode " + node.getId());

		for ( int p = 0 ; p < node.sizeOfPortArray() ; p++ ) {
			printPort( node.getPortArray( p), indent + "  ");
		}
		
		for ( int d = 0 ; d < node.sizeOfDataArray() ; d++ ) {
			printData( node.getDataArray( d), indent + "  ");
		}
		
		GraphType graph = node.getGraph();
		if ( graph != null ) 
			printGraph( graph, indent + "  ");
	}
		
	static public void printEdge( EdgeType e, String indent) {
		System.out.println( indent + "printEdge " + e.getId() + ": " +
			e.getSource() + " --> " + e.getTarget());
	}

	static void printData( DataType d, String indent) {
		System.out.println( indent + "printData " + d.getId() + " key " + d.getKey());
	}

	static void printPort( PortType p, String indent) {
		System.out.println( indent + "printPort " + p.getName());
	}

	static public void renameGraphIds( GraphType graph, String newGraphId) {
		if ( graph.getId() != null ) 
			graph.setId( newGraphId + MTBProcessingDAG.idSeparator + 
                 MTBProcessingDAG.removeGraphId( graph.getId()));

		for ( int n = 0 ; n < graph.sizeOfNodeArray() ; n++ ) {
			renameNodeIds( graph.getNodeArray( n), newGraphId);
		}

		for ( int e = 0 ; e < graph.sizeOfEdgeArray() ; e++ ) {
			renameEdgeIds( graph.getEdgeArray( e), newGraphId);
		}

		for ( int d = 0 ; d < graph.sizeOfDataArray() ; d++ ) {
			renameDataIds( graph.getDataArray( d), newGraphId);
		}
	}

	static public void renameNodeIds( NodeType node, String newGraphId) {
		if ( node.getId() != null ) 
		node.setId( newGraphId + MTBProcessingDAG.idSeparator +
				MTBProcessingDAG.removeGraphId( node.getId()));

		// rename data attriputes
		for ( int n = 0 ; n < node.sizeOfDataArray() ; n++ ) {
			DataType data = node.getDataArray( n);
			if ( data.getKey().equals( "mtbOutput") ) { //|| 
				
				String value = data.newCursor().getTextValue();
				if ( value != null )  {
					data.set( XmlString.Factory.newValue( 
					    newGraphId + MTBProcessingDAG.idSeparator +
						MTBProcessingDAG.removeGraphId( value)));
	
					if ( debug ) 
						System.out.println( "renameDataIds: " + value);
				}
			}
		}

		GraphType g = node.getGraph();
		if ( g != null ) 
			renameGraphIds( g, newGraphId);
	}
		
	static void renameEdgeIds( EdgeType e, String newGraphId) {
		if ( e.getId() != null ) 
			e.setId( newGraphId + MTBProcessingDAG.idSeparator +
				MTBProcessingDAG.removeGraphId( e.getId()));

		if ( e.getSource() != null )
			e.setSource( newGraphId + MTBProcessingDAG.idSeparator +
				MTBProcessingDAG.removeGraphId( e.getSource()));

		if ( e.getTarget() != null )
			e.setTarget( newGraphId + MTBProcessingDAG.idSeparator +
				MTBProcessingDAG.removeGraphId( e.getTarget()));
	}

	static void renameDataIds( DataType data, String newGraphId) {
		if ( data.getId() != null ) 
			data.setId( newGraphId + MTBProcessingDAG.idSeparator +
			     MTBProcessingDAG.removeGraphId( data.getId()));

		// mtbOutput: rename of output port of top level graph
		if ( data.getKey().equals( "mtbOutput") ) { //|| 
			String value = data.newCursor().getTextValue();
			if ( value != null )  {
				data.set( XmlString.Factory.newValue( 
					   newGraphId + MTBProcessingDAG.idSeparator +
					MTBProcessingDAG.removeGraphId( value)));
			}
		}
	}

	/** Return the first element of type Graph found at the top level of the
	 *  graphml object
	 *
	 * @param	graphml	complete graphml object
	 * @return	first top level graph object or null if none found
	 */
	public static GraphType getToplevelGraph( GraphmlType graphml) {
		if ( graphml.sizeOfGraphArray() > 0 )
			return graphml.getGraphArray(0);
		else
			return null;
    }

}
