/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;

import java.util.*;


class MTBParameterWrapper {
	private final String className;
	private final String packageName;
	private final String version;
	private Hashtable<String, Object> parameterHash;

	MTBParameterWrapper( MTBOperator op) {
		className = op.getClass().getSimpleName();
		if ( op.getClass().getPackage() != null ) 
			packageName = op.getClass().getPackage().getName();
		else
			packageName = new String( "no package");
		version = VersionInfo.getCvsTag();
		this.parameterHash = op.cloneParameters();
	}

	String getClassName() {
		return className;
	}

	String getPackageName() {
		return packageName;
	}

	String getVersion() {
		return version;
	}

	Hashtable<String, Object> getParameteres() {
		return parameterHash;
	}
}
