/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package mtb_morphology;

import ij.*;
import ij.process.ImageProcessor;

import de.unihalle.informatik.MiToBo.datatypes.images.MTBImage;
import de.unihalle.informatik.MiToBo.exceptions.MTBException;
import de.unihalle.informatik.MiToBo.exceptions.MTBOperatorException;
import de.unihalle.informatik.MiToBo.exceptions.MTBProcessingDAGException;
import de.unihalle.informatik.MiToBo.morphology.*;
import de.unihalle.informatik.MiToBo.morphology.GrayscaleMorphology.gwMorphOp;
import de.unihalle.informatik.MiToBo.operator.MTBOpArgumentDescriptor;
import de.unihalle.informatik.MiToBo.operator.MTBOperatorPlugInFilter;

/**
 * Convex top hat operator on grayscale images.
 * 
 * @author moeller
 */
public class TopHat_Convex extends MTBOperatorPlugInFilter
{
	
	@Override
  protected void collectArguments() throws MTBOperatorException{
        super.collectArguments();

		MTBOpArgumentDescriptor[] inputDescriptors = null; 
		MTBOpArgumentDescriptor[] outputDescriptors = 
			new MTBOpArgumentDescriptor[] {
				new MTBOpArgumentDescriptor("resultImg", MTBImage.class, 
											"Result image", true, null)
			};
		
		MTBOpArgumentDescriptor[] parameterDescriptors = 
			new MTBOpArgumentDescriptor[] {
				new MTBOpArgumentDescriptor("masksize", Integer.class, 
											"Masksize", true, new Integer(3)),
				new MTBOpArgumentDescriptor("processMode", gwMorphOp.class, 
											"Mode", true, GrayscaleMorphology.gwMorphOp.GWM_TOPHAT_CONVEX)
			};
	
		MTBOpArgumentDescriptor[] supplementalDescriptors = null;
	
			addDescriptors(parameterDescriptors, inputDescriptors, 
					        outputDescriptors, supplementalDescriptors);
	}

	public TopHat_Convex() throws MTBOperatorException {
		// nothing to do here
	}
	
	
	@Override
	public int setup(String arg, ImagePlus imp) {
		super.setup(arg,imp);
		return DOES_8G + DOES_16;
	}

	@Override
	public void operate() 
		throws MTBOperatorException, MTBProcessingDAGException {

		GrayscaleMorphology gwMorph = new GrayscaleMorphology((MTBImage)this.getInput("inImg"),
										(gwMorphOp)this.getParameter("processMode"),
										((Integer)this.getParameter("masksize")).intValue());
		gwMorph.runOp(this);
		this.setOutput("resultImg",gwMorph.getResultImage());
	}

	@Override
  public void run(ImageProcessor arg0) {
		// get mask size from user
		int masksize= -1;
		while (masksize < 0) {
			masksize= (int)IJ.getNumber("Enter masksize (3, 5, 7, ...): ", 3);
			if (masksize < 0)
				IJ.error("Please enter a positive number!");
		}
		// set inputs and parameters
		try {
	    this.setInput("inImg", this.mtbInput);
			this.setParameter("masksize", new Integer(masksize));
			this.setParameter("processMode", GrayscaleMorphology.gwMorphOp.GWM_TOPHAT_CONVEX);
			this.runOp(null);
			((MTBImage)this.getOutput("resultImg")).show();
    } catch (MTBException e) {
	    // TODO Auto-generated catch block
	    e.printStackTrace();
    }
	}
	
	
	

//	@Override
//	public boolean operate(MTBOpParams p) {
//
//		// get mask size from user
//		int masksize= -1;
//		while (masksize < 0) {
//			masksize= (int)IJ.getNumber("Enter masksize (3, 5, 7, ...): ", 3);
//			if (masksize < 0)
//				IJ.error("Please enter a positive number!");
//		}
//		GrayscaleMorphology gwMorph= new GrayscaleMorphology();
//		GrayscaleMorphParams gwmParams= 
//			gwMorph.new GrayscaleMorphParams(p.getMetaDataObject(),
//						this.mtbInput,
//						GrayscaleMorphology.gwMorphOp.GWM_TOPHAT_CONVEX,
//						masksize);
//		gwMorph.runOp(gwmParams);
//		
//		// make result image accessible for MTBOpPluginBase
//		p.setParameter("mtb_resultimage", gwmParams.getResultImage());
//		return true;
//	}
}
